Welcome to ClientVPS Mirrors

Help for package ROI.plugin.cplex
Version: 0.3-0
Title: ROI Plug-in CPLEX
Description: Enhances the R Optimization Infrastructure (ROI) package by registering the 'CPLEX' commercial solver. It allows for solving mixed integer quadratically constrained programming (MIQPQC) problems as well as all variants/combinations of LP, QP, QCP, IP.
Imports: methods, ROI (≥ 0.3-0), Rcplex (≥ 0.3-3), slam
License: GPL-3
URL: http://R-Forge.R-project.org/projects/roi
NeedsCompilation: no
Packaged: 2017-10-20 20:12:40 UTC; theussl
Author: Stefan Theussl [aut, cre], Florian Schwendinger [ctb]
Maintainer: Stefan Theussl <Stefan.Theussl@R-Project.org>
Repository: CRAN
Date/Publication: 2017-10-20 21:10:11 UTC

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.